import {  //importing functions
  select, 
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';


const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// minutes
const numberFormat = number =>
  	(Math.abs(Number(number))) + " min"  ;

//construction of pie 
const render = data => {
  const pieData = pie().sort(null).value(d=>d.Runtime)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Runtime))
  	.on("mouseover", d => console.log(d.data.Runtime));
  
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  
  // list of each movie name as labels and their run time

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.Runtime));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.Series_Title);
  legend.append("text")
  	.attr("x", 380)
  	.attr("y", 18)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Runtime));
}

// url of my data gist

const csvUrl =
'https://gist.githubusercontent.com/Harshavardhan-manne-tamu/b2b3747e28f296e397104b4a1d4d73b2/raw/416f5846d3aa607857f8193672216808181da2dd/movie_data.csv';

csv(csvUrl).then(csvData => {
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});